You will need CMake and Boost to build this

``` 
sudo apt-get install cmake libboost-dev libboost-log-dev libboost-log-program-options-dev
```


Plus libbson

```
sudo apt-get install libbson-1.0-0
```

or in OSX

```
brew install mongo-c-driver
```

Also, yaml-cpp

```
sudo apt install libyaml-cpp-dev
```

or built locally downloading and building
```
https://github.com/mongodb/mongo-c-driver/tree/master/src/libbson
https://github.com/jbeder/yaml-cpp/
```
